@@ -1,3 +1,7 @@
+"""
+This file contains all models.
+"""
+
 import six
 from enum import Enum
 from yaml import dump
@@ -5,10 +9,6 @@ from yaml import dump
 from typecraft_python.parsing.mappings import get_pos_conversions, get_gloss_conversions
 from typecraft_python.core.interfaces import TypecraftModel
 
-"""
-This file contains all models.
-"""
-
 
 class Corpus(TypecraftModel):
     """
@@ -483,7 +483,7 @@ class Word(TypecraftModel):
         ipa="",
         pos="",
         stem_morpheme=None,
-        morphemes=[]
+        morphemes=None
     ):
         """
         Default constructor.
@@ -492,8 +492,7 @@ class Word(TypecraftModel):
         self.ipa = ipa
         self.pos = pos
         self.stem_morpheme = stem_morpheme
-        self.morphemes = []
-        self.add_morphemes(morphemes)
+        self.morphemes = morphemes or []
 
     def add_morpheme(self, morpheme):
         """
