@@ -1,8 +1,11 @@
-import six
 
+# Define these below batch to avoid circular dependency
+from typecraft_python.integrations.obt.tagger import ObtTagger
 from typecraft_python.integrations.nltk.tagger import NltkTagger
 from typecraft_python.integrations.treetagger import TreeTagger
 
+import six
+
 
 def batch(iterable, n=1):
     length = len(iterable)
@@ -18,6 +21,8 @@ def split(a, n):
 
 TAGGER_TRANSLATIONS = {
     'tree': TreeTagger,
+    'obt': ObtTagger,
+    'nltk': NltkTagger
 }
 
 
@@ -27,9 +32,10 @@ def get_tagger_by_name(name):
     name_lower = name.lower()
     if 'tree' in name_lower:
         return TreeTagger
-    # Nltk
     if 'nl' in name_lower:
         return NltkTagger
+    if 'ob' in name_lower:
+        return ObtTagger
 
     raise ValueError("Tagger %s not found" % (name,))
 
